@@ -65,7 +65,8 @@ class Ui_MainWindow(QWidget):
 			QMessageBox.critical(self, "Critical",  myPath + " '" + self.options[myPath] + "' not found!")
         		widget = pathWindow(self)
 			widget.show()
-	if not os.path.exists(self.options["biospath"] + "/sfix.sfx"):
+	if not (os.path.exists(self.options["biospath"] + "/sfix.sfx")) \
+	and not (os.path.exists(self.options["biospath"] + "/sfix.sfix")):
 		QMessageBox.critical(self, "Warning",  "Cannot find all bios files in " + self.options["biospath"])
 	if not os.path.exists(self.options["romrcdir"] + "/kof96.rc"):
 		QMessageBox.critical(self, "Warning",  "Cannot find romrc files in " + self.options["romrcdir"])
@@ -192,37 +193,37 @@ class ConfigWindow(QMainWindow):
         font.setPointSize(20)
 	#showfps
         self.showfpsCheckBox = QCheckBox("Showfps",self)
-        self.showfpsCheckBox.setGeometry(QRect(18, 30, 250, 60))
+        self.showfpsCheckBox.setGeometry(QRect(18, 15, 250, 60))
         self.showfpsCheckBox.setFont(font)
 	if self.options["showfps"] == "true":
             self.showfpsCheckBox.setChecked(True)
 	#fullscreen
         self.fullscreenCheckBox = QCheckBox("Fullscreen",self)
-        self.fullscreenCheckBox.setGeometry(QRect(273, 30, 250, 60))
+        self.fullscreenCheckBox.setGeometry(QRect(273, 15, 250, 60))
         self.fullscreenCheckBox.setFont(font)
 	if self.options["fullscreen"] == "true":
             self.fullscreenCheckBox.setChecked(True)
 	#sound
         self.soundCheckBox = QCheckBox("Sound",self)
-        self.soundCheckBox.setGeometry(QRect(530, 30, 250, 60))
+        self.soundCheckBox.setGeometry(QRect(530, 15, 250, 60))
         self.soundCheckBox.setFont(font)
 	if self.options["sound"] == "true":
             self.soundCheckBox.setChecked(True)
 	#autoframeskip
         self.autoframeskipCheckBox = QCheckBox("Autoframeskip",self)
-        self.autoframeskipCheckBox.setGeometry(QRect(18, 100, 250, 60))
+        self.autoframeskipCheckBox.setGeometry(QRect(18, 85, 250, 60))
         self.autoframeskipCheckBox.setFont(font)
 	if self.options["autoframeskip"] == "true":
             self.autoframeskipCheckBox.setChecked(True)
 	#raster
         self.rasterCheckBox = QCheckBox("Raster",self)
-        self.rasterCheckBox.setGeometry(QRect(273, 100, 250, 60))
+        self.rasterCheckBox.setGeometry(QRect(273, 85, 250, 60))
         self.rasterCheckBox.setFont(font)
 	if self.options["raster"] == "true":
             self.rasterCheckBox.setChecked(True)
 	#interpolation
         self.interpolationCheckBox = QCheckBox("Interpolation",self)
-        self.interpolationCheckBox.setGeometry(QRect(530, 100, 250, 60))
+        self.interpolationCheckBox.setGeometry(QRect(530, 85, 250, 60))
         self.interpolationCheckBox.setFont(font)
 	if self.options["interpolation"] == "true":
             self.interpolationCheckBox.setChecked(True)
@@ -239,11 +240,11 @@ class ConfigWindow(QMainWindow):
 	if self.options["hwsurface"] == "true":
             self.hwsurfaceCheckBox.setChecked(True)
 	#joystick
-        self.joystickCheckBox = QCheckBox("Joystick",self)
-        self.joystickCheckBox.setGeometry(QRect(530, 170, 250, 60))
-        self.joystickCheckBox.setFont(font)
-	if self.options["joystick"] == "true":
-            self.joystickCheckBox.setChecked(True)
+        #self.joystickCheckBox = QCheckBox("Joystick",self)
+        #self.joystickCheckBox.setGeometry(QRect(530, 170, 250, 60))
+        #self.joystickCheckBox.setFont(font)
+	#if self.options["joystick"] == "true":
+        #    self.joystickCheckBox.setChecked(True)
 	#system
 	label = QLabel("<i>system:</i>", self)
 	label.move(100,230)
@@ -281,14 +282,13 @@ class ConfigWindow(QMainWindow):
 		, SIGNAL("clicked()")
 		, self.on_paths_clicked)
 	# Samplerate
-	# label = QLabel("<i>samprate:</i>", self)
-	# label.move(320,320)
-        # self.comboSampleRate = QComboBox(self)
-	# self.comboSampleRate.setGeometry(QRect(273, 350, 250, 60))
-	# SampRates="8192 11025 22050 32000 44100 48000"
-	# Sam_Rates = self.listDefaultFirst("samplerate",SampRates)
-	# for SampRate in Sam_Rates:
-        # 		 	self.comboSampleRate.addItem(SampRate)
+	label = QLabel("<i>snd_rate:</i>", self)
+	label.move(595,145)
+        self.comboSampleRate = QComboBox(self)
+	self.comboSampleRate.setGeometry(QRect(530, 170, 250, 60))
+	Sam_Rates = self.listDefaultFirst("samplerate",['8192','11025','22050','32000','44100','48000'])
+	for SampRate in Sam_Rates:
+        		 	self.comboSampleRate.addItem(SampRate)
 	# Save button
         self.saveButton = QPushButton("SAVE",self)
         self.saveButton.setStyleSheet(
@@ -325,13 +325,13 @@ class ConfigWindow(QMainWindow):
         if self.hwsurfaceCheckBox.isChecked():
            self.options["hwsurface"] = "true"
         else: self.options["hwsurface"] = "false" 
-        if self.joystickCheckBox.isChecked():
-           self.options["joystick"] = "true"
-        else: self.options["joystick"] = "false" 
+        #if self.joystickCheckBox.isChecked():
+        #   self.options["joystick"] = "true"
+        #else: self.options["joystick"] = "false" 
 	self.options["system"] = self.comboSystem.currentText()
 	self.options["country"] = self.comboCountry.currentText()
 	self.options["effect"] = self.comboEffect.currentText()
-	#self.options["samplerate"] = self.comboSampleRate.currentText()
+	self.options["samplerate"] = self.comboSampleRate.currentText()
 	if BiosPath != "":
 		self.options["biospath"] = BiosPath
 	if RomrcPath != "":
